==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/VerifyDocumentResult.java <==
package com.example.model;

/**
 * Model for VerifyDocumentResult
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "VerifyDocumentResult", description = "Model for VerifyDocumentResult")
@javax.xml.bind.annotation.XmlRootElement(name = "VerifyDocumentResult")
public class VerifyDocumentResult implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String activityId = null;
	private com.example.model.Attributes attributes = null;
	private java.lang.String originatingAgencyCode = null;
	private java.lang.String verificationRequestNumber = null;
	private java.lang.String verificationResultCode = null;
	
	/**
	 */
	public VerifyDocumentResult activityId(java.lang.String activityId) {
		setActivityId(activityId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ActivityId")
	@javax.validation.constraints.NotNull
	public java.lang.String getActivityId() {
		return this.activityId;
	}
	public void setActivityId(java.lang.String activityId) {
		this.activityId = activityId;
	}
	
	/**
	 * Model for Attributes
	 */
	public VerifyDocumentResult attributes(com.example.model.Attributes attributes) {
		setAttributes(attributes);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for Attributes")
	@com.fasterxml.jackson.annotation.JsonProperty("attributes")
	@javax.validation.Valid
	public com.example.model.Attributes getAttributes() {
		return this.attributes;
	}
	public void setAttributes(com.example.model.Attributes attributes) {
		this.attributes = attributes;
	}
	
	/**
	 */
	public VerifyDocumentResult originatingAgencyCode(java.lang.String originatingAgencyCode) {
		setOriginatingAgencyCode(originatingAgencyCode);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("OriginatingAgencyCode")
	public java.lang.String getOriginatingAgencyCode() {
		return this.originatingAgencyCode;
	}
	public void setOriginatingAgencyCode(java.lang.String originatingAgencyCode) {
		this.originatingAgencyCode = originatingAgencyCode;
	}
	
	/**
	 */
	public VerifyDocumentResult verificationRequestNumber(java.lang.String verificationRequestNumber) {
		setVerificationRequestNumber(verificationRequestNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("VerificationRequestNumber")
	public java.lang.String getVerificationRequestNumber() {
		return this.verificationRequestNumber;
	}
	public void setVerificationRequestNumber(java.lang.String verificationRequestNumber) {
		this.verificationRequestNumber = verificationRequestNumber;
	}
	
	/**
	 */
	public VerifyDocumentResult verificationResultCode(java.lang.String verificationResultCode) {
		setVerificationResultCode(verificationResultCode);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("VerificationResultCode")
	public java.lang.String getVerificationResultCode() {
		return this.verificationResultCode;
	}
	public void setVerificationResultCode(java.lang.String verificationResultCode) {
		this.verificationResultCode = verificationResultCode;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		VerifyDocumentResult verifyDocumentResult = (VerifyDocumentResult) o;
		return java.util.Objects.equals(this.activityId, verifyDocumentResult.activityId)
				&& java.util.Objects.equals(this.attributes, verifyDocumentResult.attributes)
				&& java.util.Objects.equals(this.originatingAgencyCode, verifyDocumentResult.originatingAgencyCode)
				&& java.util.Objects.equals(this.verificationRequestNumber, verifyDocumentResult.verificationRequestNumber)
				&& java.util.Objects.equals(this.verificationResultCode, verifyDocumentResult.verificationResultCode);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.activityId, this.attributes, this.originatingAgencyCode, this.verificationRequestNumber, this.verificationResultCode);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class VerifyDocumentResult {\n");
		
		sb.append("    activityId: ").append(toIndentedString(this.activityId)).append("\n");
		sb.append("    attributes: ").append(toIndentedString(this.attributes)).append("\n");
		sb.append("    originatingAgencyCode: ").append(toIndentedString(this.originatingAgencyCode)).append("\n");
		sb.append("    verificationRequestNumber: ").append(toIndentedString(this.verificationRequestNumber)).append("\n");
		sb.append("    verificationResultCode: ").append(toIndentedString(this.verificationResultCode)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/VerifyDocumentResult.java <==
package com.example.model;

/**
 * Model for VerifyDocumentResult
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "VerifyDocumentResult", description = "Model for VerifyDocumentResult")
@javax.xml.bind.annotation.XmlRootElement(name = "VerifyDocumentResult")
public class VerifyDocumentResult implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String activityId = null;
	private com.example.model.Attributes attributes = null;
	private java.lang.String originatingAgencyCode = null;
	private java.lang.String verificationRequestNumber = null;
	private java.lang.String verificationResultCode = null;
	
	/**
	 */
	public VerifyDocumentResult activityId(java.lang.String activityId) {
		setActivityId(activityId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "ActivityId")
	@com.fasterxml.jackson.annotation.JsonProperty("ActivityId")
	@javax.validation.constraints.NotNull
	public java.lang.String getActivityId() {
		return this.activityId;
	}
	public void setActivityId(java.lang.String activityId) {
		this.activityId = activityId;
	}
	
	/**
	 * Model for Attributes
	 */
	public VerifyDocumentResult attributes(com.example.model.Attributes attributes) {
		setAttributes(attributes);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "attributes", description = "Model for Attributes")
	@com.fasterxml.jackson.annotation.JsonProperty("attributes")
	@javax.validation.Valid
	public com.example.model.Attributes getAttributes() {
		return this.attributes;
	}
	public void setAttributes(com.example.model.Attributes attributes) {
		this.attributes = attributes;
	}
	
	/**
	 */
	public VerifyDocumentResult originatingAgencyCode(java.lang.String originatingAgencyCode) {
		setOriginatingAgencyCode(originatingAgencyCode);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "OriginatingAgencyCode")
	@com.fasterxml.jackson.annotation.JsonProperty("OriginatingAgencyCode")
	public java.lang.String getOriginatingAgencyCode() {
		return this.originatingAgencyCode;
	}
	public void setOriginatingAgencyCode(java.lang.String originatingAgencyCode) {
		this.originatingAgencyCode = originatingAgencyCode;
	}
	
	/**
	 */
	public VerifyDocumentResult verificationRequestNumber(java.lang.String verificationRequestNumber) {
		setVerificationRequestNumber(verificationRequestNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "VerificationRequestNumber")
	@com.fasterxml.jackson.annotation.JsonProperty("VerificationRequestNumber")
	public java.lang.String getVerificationRequestNumber() {
		return this.verificationRequestNumber;
	}
	public void setVerificationRequestNumber(java.lang.String verificationRequestNumber) {
		this.verificationRequestNumber = verificationRequestNumber;
	}
	
	/**
	 */
	public VerifyDocumentResult verificationResultCode(java.lang.String verificationResultCode) {
		setVerificationResultCode(verificationResultCode);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "VerificationResultCode")
	@com.fasterxml.jackson.annotation.JsonProperty("VerificationResultCode")
	public java.lang.String getVerificationResultCode() {
		return this.verificationResultCode;
	}
	public void setVerificationResultCode(java.lang.String verificationResultCode) {
		this.verificationResultCode = verificationResultCode;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		VerifyDocumentResult verifyDocumentResult = (VerifyDocumentResult) o;
		return java.util.Objects.equals(this.activityId, verifyDocumentResult.activityId)
				&& java.util.Objects.equals(this.attributes, verifyDocumentResult.attributes)
				&& java.util.Objects.equals(this.originatingAgencyCode, verifyDocumentResult.originatingAgencyCode)
				&& java.util.Objects.equals(this.verificationRequestNumber, verifyDocumentResult.verificationRequestNumber)
				&& java.util.Objects.equals(this.verificationResultCode, verifyDocumentResult.verificationResultCode);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.activityId, this.attributes, this.originatingAgencyCode, this.verificationRequestNumber, this.verificationResultCode);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class VerifyDocumentResult {\n");
		
		sb.append("    activityId: ").append(toIndentedString(this.activityId)).append("\n");
		sb.append("    attributes: ").append(toIndentedString(this.attributes)).append("\n");
		sb.append("    originatingAgencyCode: ").append(toIndentedString(this.originatingAgencyCode)).append("\n");
		sb.append("    verificationRequestNumber: ").append(toIndentedString(this.verificationRequestNumber)).append("\n");
		sb.append("    verificationResultCode: ").append(toIndentedString(this.verificationResultCode)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
